structure(
  list(
    url = "__api__/v1/applications/01234567/thumbnail",
    status_code = 404L,
    content = charToRaw("404 page not found")
  ),
  class = "response"
)
